@@ -198,24 +198,24 @@ create_pixelformat_function_table(const gavl_video_options_t * opt,
                                  int width, int height)
   {
   gavl_pixelformat_function_table_t * csp_tab;
-  int real_accel_flags = opt->accel_flags ?
-    gavl_real_accel_flags(opt->accel_flags) : 0;
     
   csp_tab =
     calloc(1,sizeof(gavl_pixelformat_function_table_t));
-#if 1
-  if(!real_accel_flags || (real_accel_flags & GAVL_ACCEL_C))
+
+  //  fprintf(stderr, "create_pixelformat_function_table, flags: %08x, q: %d\n",
+  //          opt->accel_flags, opt->quality);
+  
+  /* Standard C-routines, always complete */
+  if(opt->quality || (opt->accel_flags & GAVL_ACCEL_C))
     {
-    //    fprintf(stderr, "Init C functions %08x\n", real_accel_flags);
     gavl_init_rgb_rgb_funcs_c(csp_tab, opt);
     gavl_init_rgb_yuv_funcs_c(csp_tab, opt);
     gavl_init_yuv_rgb_funcs_c(csp_tab, opt);
     gavl_init_yuv_yuv_funcs_c(csp_tab, opt);
     }
-#endif
   
-#ifdef ARCH_X86
-  if(!real_accel_flags || (real_accel_flags & GAVL_ACCEL_MMX))
+#ifdef HAVE_MMX
+  if(opt->accel_flags & GAVL_ACCEL_MMX)
     {
     //    fprintf(stderr, "Init MMX functions %08x\n", real_accel_flags);
     gavl_init_rgb_rgb_funcs_mmx(csp_tab, width, opt);
@@ -223,7 +223,7 @@ create_pixelformat_function_table(const gavl_video_options_t * opt,
     gavl_init_yuv_yuv_funcs_mmx(csp_tab, width, opt);
     gavl_init_yuv_rgb_funcs_mmx(csp_tab, width, opt);
     }
-  if(!real_accel_flags || (real_accel_flags & GAVL_ACCEL_MMXEXT))
+  if(opt->accel_flags & GAVL_ACCEL_MMXEXT)
     {
     //    fprintf(stderr, "Init MMXEXT functions %08x\n", real_accel_flags);
     gavl_init_rgb_rgb_funcs_mmxext(csp_tab, width, opt);
@@ -232,6 +232,20 @@ create_pixelformat_function_table(const gavl_video_options_t * opt,
     gavl_init_yuv_rgb_funcs_mmxext(csp_tab, width, opt);
     }
 #endif
+
+  /* High quality */
+  
+  if((opt->quality > 3) ||
+     ((!opt->quality) && (opt->accel_flags & GAVL_ACCEL_C_HQ)))
+    {
+    //    fprintf(stderr, "Init HQ\n");
+    gavl_init_rgb_rgb_funcs_hq(csp_tab, opt);
+    gavl_init_rgb_yuv_funcs_hq(csp_tab, opt);
+    gavl_init_yuv_rgb_funcs_hq(csp_tab, opt);
+    gavl_init_yuv_yuv_funcs_hq(csp_tab, opt);
+    }
+
+
   return csp_tab;
   }
 
@@ -2595,8 +2609,8 @@ int gavl_pixelformat_can_scale(gavl_pixelformat_t in_csp, gavl_pixelformat_t out
 
   if(!gavl_pixelformat_is_planar(in_csp))
     {
-    fprintf(stderr, "BLUPPPP: %d %d\n", gavl_pixelformat_is_planar(out_csp),
-            gavl_pixelformat_bytes_per_component(out_csp));
+    // fprintf(stderr, "BLUPPPP: %d %d\n", gavl_pixelformat_is_planar(out_csp),
+    //         gavl_pixelformat_bytes_per_component(out_csp));
     
     if(gavl_pixelformat_is_planar(out_csp) &&
        (gavl_pixelformat_bytes_per_component(out_csp) == 1))
