@@ -2,7 +2,7 @@
 
   gavl.h
 
-  Copyright (c) 2001-2005 by Burkhard Plaum - plaum@ipf.uni-stuttgart.de
+  Copyright (c) 2001-2006 by Burkhard Plaum - plaum@ipf.uni-stuttgart.de
 
   http://gmerlin.sourceforge.net
 
@@ -83,6 +83,35 @@ typedef struct gavl_video_format_s gavl_video_format_t;
 
 #define GAVL_QUALITY_DEFAULT 2 
 
+/** \defgroup accel_flags Acceleration flags
+ *  \brief CPU specific acceleration flags
+ *
+ *  These flags are used internally by gavl to obtain the supported
+ *  acceleration mechanisms at runtime. Some applications however might
+ *  need them as well for other tasks, so they are exported into the
+ *  public API.
+ *
+ *  @{
+ */
+  
+#define GAVL_ACCEL_MMX      (1<<0) //!< MMX
+#define GAVL_ACCEL_MMXEXT   (1<<1) //!< Extended MMX (a.k.a MMX2)
+#define GAVL_ACCEL_SSE      (1<<2) //!< Intel SSE
+#define GAVL_ACCEL_SSE2     (1<<3) //!< Intel SSE2
+#define GAVL_ACCEL_SSE3     (1<<4) //!< Intel SSE3
+#define GAVL_ACCEL_3DNOW    (1<<5) //!< AMD 3Dnow
+#define GAVL_ACCEL_3DNOWEXT (1<<6) //!< AMD 3Dnow ext
+
+/** \brief Get the supported acceleration flags
+ *  \returns A combination of GAVL_ACCEL_* flags.
+ */
+  
+int gavl_accel_supported();
+
+/**
+ *  @}
+ */
+  
 /** \defgroup audio Audio
  *  \brief Audio support
  */
@@ -498,6 +527,33 @@ GAVL_AUDIO_FRONT_TO_REAR_MUTE | \
 (GAVL_AUDIO_STEREO_TO_MONO_LEFT | \
 GAVL_AUDIO_STEREO_TO_MONO_RIGHT | \
 GAVL_AUDIO_STEREO_TO_MONO_MIX) /*!< Mask for converting stereo to mono */
+
+/*! \ingroup audio_options
+ *  \brief Dither mode
+ */
+
+typedef enum
+  {
+    GAVL_AUDIO_DITHER_NONE   = 0,
+    GAVL_AUDIO_DITHER_AUTO   = 1,
+    GAVL_AUDIO_DITHER_RECT   = 2,
+    GAVL_AUDIO_DITHER_TRI    = 3,
+    GAVL_AUDIO_DITHER_SHAPED = 4,
+  } gavl_audio_dither_mode_t;
+
+/*! \ingroup audio_options
+ *  \brief Resample mode
+ */
+  
+typedef enum
+  {
+    GAVL_RESAMPLE_AUTO        = 0, /*!< Set from quality */
+    GAVL_RESAMPLE_LINEAR      = 1, /*!< Linear interpolator, very fast, poor quality. */
+    GAVL_RESAMPLE_ZOH         = 2, /*!< Zero order hold interpolator, very fast, poor quality. */
+    GAVL_RESAMPLE_SINC_FAST   = 3, /*!< Band limited sinc interpolation, fastest, 97dB SNR, 80% BW. */
+    GAVL_RESAMPLE_SINC_MEDIUM = 4, /*!< Band limited sinc interpolation, medium quality, 97dB SNR, 90% BW. */
+    GAVL_RESAMPLE_SINC_BEST   = 5  /*!< Band limited sinc interpolation, best quality, 97dB SNR, 96% BW. */
+  } gavl_resample_mode_t;
   
 /*! \ingroup audio_options
  *  \brief Opaque container for audio conversion options.
@@ -515,6 +571,22 @@ typedef struct gavl_audio_options_s gavl_audio_options_t;
   
 void gavl_audio_options_set_quality(gavl_audio_options_t * opt, int quality);
 
+/*! \ingroup audio_options
+ *  \brief Set the dither mode for the converter
+ *  \param opt Audio options
+ *  \param mode A dither mode
+ */
+  
+void gavl_audio_options_set_dither_mode(gavl_audio_options_t * opt, gavl_audio_dither_mode_t mode);
+
+/*! \ingroup audio_options
+ *  \brief Set the resample mode for the converter
+ *  \param opt Audio options
+ *  \param mode A resample mode
+ */
+  
+void gavl_audio_options_set_resample_mode(gavl_audio_options_t * opt, gavl_resample_mode_t mode);
+  
 /*! \ingroup audio_options
  *  \brief Set the conversion flags
  *  \param opt Audio options
@@ -539,6 +611,35 @@ int gavl_audio_options_get_conversion_flags(gavl_audio_options_t * opt);
   
 void gavl_audio_options_set_defaults(gavl_audio_options_t * opt);
 
+/*! \ingroup audio_options
+ *  \brief Create an options container
+ *  \returns Newly allocated udio options with default values
+ *
+ *  Use this to store options, which will apply for more than
+ *  one converter instance. Applying the options will be done by
+ *  gavl_*_get_options() followed by gavl_audio_options_copy().
+ */
+  
+gavl_audio_options_t * gavl_audio_options_create();
+
+/*! \ingroup audio_options
+ *  \brief Copy audio options
+ *  \param dst Destination
+ *  \param src Source
+ */
+
+void gavl_audio_options_copy(gavl_audio_options_t * dst,
+                             const gavl_audio_options_t * src);
+
+/*! \ingroup audio_options
+ *  \brief Destroy audio options
+ *  \param opt Audio options
+ */
+
+void gavl_audio_options_destroy(gavl_audio_options_t * opt);
+  
+  
+  
 /* Audio converter */
 
 /** \defgroup audio_converter Audio converter
@@ -600,14 +701,6 @@ void gavl_audio_converter_destroy(gavl_audio_converter_t* cnv);
 
 gavl_audio_options_t * gavl_audio_converter_get_options(gavl_audio_converter_t*cnv);
 
-/*! \ingroup audio_converter
- *  \brief Copies audio options
- *  \param src Source
- *  \param dst Destination
- *
- */
-void gavl_audio_options_copy(gavl_audio_options_t * dst,
-                             const gavl_audio_options_t * src);
 
 /*! \ingroup audio_converter
  *  \brief Initialize an audio converter
@@ -704,8 +797,82 @@ void gavl_volume_control_set_volume(gavl_volume_control_t * ctrl,
   
 void gavl_volume_control_apply(gavl_volume_control_t *ctrl,
                                gavl_audio_frame_t * frame);
-  
 
+/** \defgroup peak_detection Peak detector
+    \ingroup audio
+    \brief Detect peaks in the volume for steering normalizers and
+      dynamic range compressors
+
+    While normalizers and dynamic range controls are out of the scope
+    of gavl, some low-level functionality can be provided
+*/
+ 
+/*! \ingroup peak_detection
+ *  \brief Opaque structure for peak detector
+ *
+ * You don't want to know what's inside.
+ */
+
+typedef struct gavl_peak_detector_s gavl_peak_detector_t;
+  
+/* Create / destroy */
+
+/*! \ingroup peak_detection
+ *  \brief Create peak detector
+ *  \returns A newly allocated peak detector
+ */
+  
+gavl_peak_detector_t * gavl_peak_detector_create();
+
+/*! \ingroup peak_detection
+ *  \brief Destroys a peak detector and frees all associated memory
+ *  \param pd A peak detector
+ */
+
+void gavl_peak_detector_destroy(gavl_peak_detector_t *pd);
+
+/*! \ingroup peak_detection
+ *  \brief Set format for a peak detector
+ *  \param pd A peak detector
+ *  \param format The format subsequent frames will be passed with
+ *
+ * This function can be called multiple times with one instance. It also
+ * calls \ref gavl_peak_detector_reset.
+ */
+
+void gavl_peak_detector_set_format(gavl_peak_detector_t *pd,
+                                    gavl_audio_format_t * format);
+
+/*! \ingroup peak_detection
+ *  \brief Feed the peak detector with a new frame
+ *  \param pd A peak detector
+ *  \param frame An audio frame
+ */
+  
+void gavl_peak_detector_update(gavl_peak_detector_t *pd,
+                              gavl_audio_frame_t * frame);
+  
+/*! \ingroup peak_detection
+ *  \brief Get the peak volume seen so far
+ *  \param pd A peak detector
+ *  \param min Returns minimum amplitude
+ *  \param max Returns maximum amplitude
+ *
+ *  The returned amplitudes are normalized such that the
+ *  minimum amplitude corresponds to -1.0, the maximum amplitude
+ *  corresponds to 1.0.
+ */
+  
+void gavl_peak_detector_get_peak(gavl_peak_detector_t * pd,
+                                 double * min, double * max);
+
+/*! \ingroup peak_detection
+ *  \brief Reset a peak detector
+ *  \param pd A peak detector
+ */
+  
+void gavl_peak_detector_reset(gavl_peak_detector_t * pd);
+  
 /** \defgroup video Video
  *
  * Video support
@@ -1415,7 +1582,7 @@ typedef struct gavl_video_frame_s
   
   void * user_data;    /*!< For storing user data (e.g. the corresponding XImage) */
   int64_t time_scaled; /*!< Timestamp in stream specific units (see \ref video_format) */
-  int duration_scaled; /*!< Duration in stream specific units (see \ref video_format) */
+  int64_t duration_scaled; /*!< Duration in stream specific units (see \ref video_format) */
   } gavl_video_frame_t;
 
 
@@ -1480,6 +1647,20 @@ void gavl_video_frame_null(gavl_video_frame_t*frame);
 
 void gavl_video_frame_clear(gavl_video_frame_t * frame,
                             gavl_video_format_t * format);
+
+/*!
+  \ingroup video_frame
+  \brief Fill the frame with a user spefified color
+  \param frame A video frame
+  \param format Format of the data in the frame
+  \param color Color components in RGBA format scaled 0.0 .. 1.0
+ 
+*/
+
+void gavl_video_frame_fill(gavl_video_frame_t * frame,
+                           gavl_video_format_t * format,
+                           float * color);
+
   
 /*!
   \ingroup video_frame
@@ -1711,6 +1892,34 @@ typedef struct gavl_video_options_s gavl_video_options_t;
   
 void gavl_video_options_set_defaults(gavl_video_options_t * opt);
 
+/*! \ingroup video_options
+ *  \brief Create an options container
+ *  \returns Newly allocated udio options with default values
+ *
+ *  Use this to store options, which will apply for more than
+ *  one converter instance. Applying the options will be done by
+ *  gavl_*_get_options() followed by gavl_video_options_copy().
+ */
+  
+gavl_video_options_t * gavl_video_options_create();
+
+/*! \ingroup video_options
+ *  \brief Copy video options
+ *  \param dst Destination
+ *  \param src Source
+ */
+
+void gavl_video_options_copy(gavl_video_options_t * dst,
+                             const gavl_video_options_t * src);
+
+/*! \ingroup video_options
+ *  \brief Destroy video options
+ *  \param opt Video options
+ */
+
+void gavl_video_options_destroy(gavl_video_options_t * opt);
+  
+  
 /*! \ingroup video_options
  *  \brief Set source and destination rectangles
  *  \param opt Video options
@@ -2069,46 +2278,114 @@ void gavl_video_deinterlacer_deinterlace(gavl_video_deinterlacer_t * deinterlace
 /**************************************************
  * Transparent overlays 
  **************************************************/
-#if 0
-/* Overlay format */
-  
-typedef struct
-  {
-  gavl_video_format_t overlay_format;
-  gavl_video_format_t frame_format;
-  } gavl_overlay_format_t;
-    
+
 /* Overlay struct */
 
+/*! \defgroup video_blend Overlay blending
+ * \ingroup video
+ *
+ *  Overlay blending does one elemental operation:
+ *  Take a partly transparent overlay (in an alpha
+ *  capable pixelformat) and blend it onto a video frame.
+ *  Blending can be used for subtitles or OSD in playback applications,
+ *  and also for lots of weird effects.
+ *  In the current implementation, there is only one overlay
+ *  pixelformat, which can be blended onto a cetrtain destination format.
+ *  Therefore, the incoming overlay will be converted to the pixelformat
+ *  necessary for the conversion. For OSD and Subtitle applications,
+ *  this happens only once for each overlay, since the converted overlay is
+ *  remembered by the blend context.
+ *
+ *  Note that gavl doesn't (and never will) support text subtitles. To
+ *  blend text strings onto a video frame, you must render it into a
+ *  gavl_overlay_t with some typesetting library (e.g. freetype) first.
+ */
+  
+/*! \ingroup video_blend
+ *  \brief Overlay structure.
+ *
+ *  Structure, which holds an overlay. If the sizes of source and destination
+ *  rectangles differ, the smaller one will be used.
+ */
+ 
 typedef struct
   {
-  gavl_video_frame_t * frame;
-  gavl_rectangle_i_t dst_rectangle;
+  gavl_video_frame_t * frame;    //!< Video frame in an alpha capable format */
+  gavl_rectangle_i_t ovl_rect;   //!< Rectangle in the source frame     */
+  int dst_x;                     //!< x offset in the destination frame. */
+  int dst_y;                     //!< y offset in the destination frame. */
   } gavl_overlay_t;
 
-/*
- *  Blend context
+/*! \ingroup video_blend
+ *  \brief Opaque blend context.
+ *
+ *  You don't want to know what's inside.
  */
-
+  
 typedef struct gavl_overlay_blend_context_s gavl_overlay_blend_context_t;
 
+/*! \ingroup video_blend
+ *  \brief Create a blend context
+ *  \returns A newly allocated blend context.
+ */
+  
 gavl_overlay_blend_context_t * gavl_overlay_blend_context_create();
 
-void gavl_overlay_blend_context_destroy(gavl_overlay_blend_context_t *);
-void gavl_overlay_blend_context_init(gavl_overlay_blend_context_t *,
-                                     gavl_overlay_format_t *);
+/*! \ingroup video_blend
+ *  \brief Destroy a blend context and free all associated memory
+ *  \param ctx A blend context
+ */
 
+void gavl_overlay_blend_context_destroy(gavl_overlay_blend_context_t * ctx);
+
+/*! \ingroup video_blend
+ *  \brief Get options from a blend context
+ *  \param ctx A blend context
+ *  \returns Options (See \ref video_options)
+ */
+  
 gavl_video_options_t *
-gavl_overlay_blend_context_get_options(gavl_overlay_blend_context_t *);
+gavl_overlay_blend_context_get_options(gavl_overlay_blend_context_t * ctx);
 
-void gavl_overlay_blend(gavl_overlay_blend_context_t *,
+/*! \ingroup video_blend
+ *  \brief Initialize the blend context
+ *  \param ctx A blend context
+ *  \param frame_format The format of the destination frames
+ *  \param overlay_format The format of the overlays
+ * 
+ *  Initialize a blend context for a given frame- and overlayformat.
+ *  The image_width and image_height members for the overlay format represent
+ *  the maximum overlay size. The actual displayed size will be determined
+ *  by the ovl_rect of the overlay.
+ *  
+ */
+
+int gavl_overlay_blend_context_init(gavl_overlay_blend_context_t * ctx,
+                                    const gavl_video_format_t * frame_format,
+                                    const gavl_video_format_t * overlay_format);
+
+/*! \ingroup video_blend
+ *  \brief Set a new overlay
+ *  \param ctx A blend context
+ *  \param ovl An overlay
+ * 
+ *  This function sets a new overlay, regardless of whether the last one has expired
+ *  or not.
+ */
+  
+void gavl_overlay_blend_context_set_overlay(gavl_overlay_blend_context_t * ctx,
+                                            gavl_overlay_t * ovl);
+
+/*! \ingroup video_blend
+ *  \brief Blend overlay onto video frame
+ *  \param ctx A blend context
+ *  \param dst_frame Destination frame
+ */
+  
+void gavl_overlay_blend(gavl_overlay_blend_context_t * ctx,
                         gavl_video_frame_t * dst_frame);
 
-int gavl_overlay_blend_context_need_new(gavl_overlay_blend_context_t *);
-void gavl_overlay_blend_context_set_overlay(gavl_overlay_blend_context_t *,
-                                            gavl_overlay_t *);
-
-#endif  
+  
 #ifdef __cplusplus
 }
 #endif
